@@ -51,9 +51,9 @@ AgsEditorHistory *ags_editor_history = NULL;
 GType
 ags_editor_history_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_editor_history = 0;
 
     static const GTypeInfo ags_editor_history_info = {
@@ -73,10 +73,10 @@ ags_editor_history_get_type (void)
 						     &ags_editor_history_info,
 						     0);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_editor_history);
+    g_once_init_leave(&g_define_type_id__static, ags_type_editor_history);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
