@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2015 Joël Krähemann
+ * Copyright (C) 2005-2020 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -23,11 +23,14 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <ags/audio/ags_recall.h>
+#include <ags/libags.h>
 
 #include <ags/audio/ags_channel.h>
+#include <ags/audio/ags_recall.h>
 #include <ags/audio/ags_recall_audio.h>
 
+G_BEGIN_DECLS
+
 #define AGS_TYPE_RECALL_CHANNEL                (ags_recall_channel_get_type())
 #define AGS_RECALL_CHANNEL(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_RECALL_CHANNEL, AgsRecallChannel))
 #define AGS_RECALL_CHANNEL_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST((class), AGS_TYPE_RECALL_CHANNEL, AgsRecallChannelClass))
@@ -55,8 +58,18 @@ struct _AgsRecallChannelClass
 
 GType ags_recall_channel_get_type();
 
+AgsChannel* ags_recall_channel_get_destination(AgsRecallChannel *recall_channel);
+void ags_recall_channel_set_destination(AgsRecallChannel *recall_channel,
+					AgsChannel *destination);
+
+AgsChannel* ags_recall_channel_get_source(AgsRecallChannel *recall_channel);
+void ags_recall_channel_set_source(AgsRecallChannel *recall_channel,
+				   AgsChannel *source);
+
 GList* ags_recall_channel_find_channel(GList *recall_channel, AgsChannel *source);
 
 AgsRecallChannel* ags_recall_channel_new();
 
+G_END_DECLS
+
 #endif /*__AGS_RECALL_CHANNEL_H__*/
